SoftposafsPluginWeb class

A web implementation of the SoftposafsPluginPlatform of the SoftposafsPlugin plugin.

Inheritance

Constructors

SoftposafsPluginWeb()
Constructs a SoftposafsPluginWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPOSService() → Future<String?>
inherited
getPlatformVersion() → Future<String?>
Returns a String containing the version of the platform.
override
initializeSDK() → Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDevice() → Future<String?>
inherited
startTransaction() → Future<String?>
inherited
toString() → String
A string representation of this object.
inherited
unregisterDevice() → Future<String?>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void